@@ -1,9 +1,7 @@
-import json
-
 from dataclasses import asdict, is_dataclass
 from enum import Enum, auto
 from functools import wraps
-from typing import Any, Callable, Dict, Optional, Union, cast
+from typing import Any, Callable, Dict, Optional, Union, cast, Iterable
 
 from pydantic import BaseModel, ValidationError
 from pydantic.dataclasses import dataclass as pydantic_dataclass, \
@@ -13,8 +11,11 @@ from flask import Response, jsonify, request, g
 from werkzeug.datastructures import Headers
 from werkzeug.exceptions import BadRequest
 
-from .constants import SCHEMA_QUERYSTRING_ATTRIBUTE, \
+from .constants import (
+    SCHEMA_QUERYSTRING_ATTRIBUTE,
+    SCHEMA_TAG_ATTRIBUTE,
     SCHEMA_REQUEST_ATTRIBUTE, SCHEMA_RESPONSE_ATTRIBUTE
+)
 from .typing import PydanticModel
 
 
@@ -109,6 +110,14 @@ def check_response(result, response_model: Dict[int, PydanticModel]):
     return result
 
 
+def tag(*tags: Iterable[str]) -> Callable:
+    """Add tag names to the route."""
+    def decorator(func: Callable) -> Callable:
+        setattr(func, SCHEMA_TAG_ATTRIBUTE, list(set(tags)))
+        return func
+    return decorator
+
+
 def validate(
     query_string: Optional[PydanticModel] = None,
     body: Optional[PydanticModel] = None,
@@ -127,6 +136,52 @@ def validate(
             the body source
         response:
             response model define
+
+    from dataclasses import dataclass
+    from datetime import datetime
+    from typing import Optional
+    from pydantic import BaseModel
+
+    from flask import Flask
+    from schema_validator import FlaskSchema, validate
+
+    app = Flask(__name__)
+
+    FlaskSchema(app)
+    OR
+
+    schema = FlaskSchema()
+    schema.init_app(app)
+
+    @dataclass
+    class Todo:
+        task: str
+        due: Optional[datetime]
+
+    class TodoResponse(BaseModel):
+        id: int
+        name: str
+
+    @app.post("/")
+    @validate(body=Todo, responses=TodoResponse)
+    def create_todo():
+        ... # Do something with data, e.g. save to the DB
+        return dict(id=1, name="2")
+
+    @app.put("/")
+    @validate(
+        body=Todo,
+        responses={200: TodoResponse, 400: TodoResponse}
+    )
+    def update_todo():
+        ... # Do something with data, e.g. save to the DB
+        return TodoResponse(id=1, name="123")
+
+    @tags("SOME-TAG", "OTHER-TAG")
+    class View(MethodView):
+        @validate(...)
+        def get(self):
+            return {}
     """
     if validate_path:
         pass
